@@ -14,6 +14,11 @@ PATHS = OrderedDict(
         ("highcharts-more", "https://code.highcharts.com/highcharts-more.js"),
         ("highcharts/modules/stock", "https://code.highcharts.com/modules/stock.js"),
         ("highcharts/modules/map", "https://code.highcharts.com/maps/modules/map.js"),
+        ("highcharts/modules/coloraxis", "https://code.highcharts.com/maps/modules/coloraxis.js"),
+        (
+            "highcharts/modules/marker-clusters",
+            "https://code.highcharts.com/maps/modules/marker-clusters.js",
+        ),
         ("highcharts/modules/gantt", "https://code.highcharts.com/modules/gantt.js"),
         ("highcharts/modules/exporting", "https://code.highcharts.com/modules/exporting.js"),
         ("highcharts/modules/export-data", "https://code.highcharts.com/modules/export-data.js"),
@@ -27,7 +32,7 @@ PATHS = OrderedDict(
         ("highcharts/modules/funnel", "https://code.highcharts.com/modules/funnel.js"),
         ("highcharts/modules/heatmap", "https://code.highcharts.com/modules/heatmap.js"),
         (
-            "highcharts/modules/no-data-to-display",
+            "highcharts/modules/no-data",
             "https://code.highcharts.com/modules/no-data-to-display.js",
         ),
         (
